@@ -42,8 +42,11 @@
 #include <rdsocket.h>
 #include <rdconf.h>
 #include <rdcheck_daemons.h>
+#include <rddb.h>
+#include <rdescape_string.h>
 #include <rddebug.h>
 #include <rdcmd_switch.h>
+#include <rdsvc.h>
 #include <rdsystem.h>
 
 #include <cae_socket.h>
@@ -131,6 +134,7 @@ MainObject::MainObject(QObject *parent,const char *name)
   // 
   rd_config=new RDConfig(RD_CONF_FILE);
   rd_config->load();
+  rd_config->setModuleName("caed");
 
   //
   // Make sure we're the only instance running
@@ -239,6 +243,11 @@ MainObject::MainObject(QObject *parent,const char *name)
     exit(1);
   }
 
+  //
+  // Provisioning
+  //
+  InitProvisioning();
+
   //
   // Start Up the Drivers
   //
@@ -567,6 +576,70 @@ void MainObject::updateMeters()
 }
 
 
+void MainObject::InitProvisioning() const
+{
+  QString sql;
+  RDSqlQuery *q;
+  QString err_msg;
+
+  //
+  // Provision a Host
+  //
+  if(rd_config->provisioningCreateHost()) {
+    if(!rd_config->provisioningHostTemplate().isEmpty()) {
+      sql=QString("select NAME from STATIONS where ")+
+	"NAME=\""+RDEscapeString(rd_config->stationName())+"\"";
+      q=new RDSqlQuery(sql);
+      if(!q->first()) {
+	if(RDStation::create(rd_config->stationName(),&err_msg,rd_config->provisioningHostTemplate(),rd_config->provisioningHostIpAddress())) {
+	  syslog(LOG_INFO,"created new host entry \"%s\"",
+		 (const char *)rd_config->stationName());
+	  if(!rd_config->provisioningHostShortName(rd_config->stationName()).
+	     isEmpty()) {
+	    RDStation *station=new RDStation(rd_config->stationName());
+	    station->setShortName(rd_config->
+		     provisioningHostShortName(rd_config->stationName()));
+	    delete station;
+	  }
+	}
+	else {
+	  fprintf(stderr,"caed: unable to provision host [%s]\n",
+		  (const char *)err_msg);
+	  exit(256);
+	}
+      }
+      delete q;
+    }
+  }
+
+  //
+  // Provision a Service
+  //
+  if(rd_config->provisioningCreateService()) {
+    if(!rd_config->provisioningServiceTemplate().isEmpty()) {
+      QString svcname=
+	rd_config->provisioningServiceName(rd_config->stationName());
+      sql=QString("select NAME from SERVICES where ")+
+	"NAME=\""+RDEscapeString(svcname)+"\"";
+      q=new RDSqlQuery(sql);
+      if(!q->first()) {
+	if(RDSvc::create(svcname,&err_msg,
+			 rd_config->provisioningServiceTemplate(),rd_config)) {
+	  syslog(LOG_INFO,"created new service entry \"%s\"",
+		 (const char *)svcname);
+	}
+	else {
+	  fprintf(stderr,"caed: unable to provision service [%s]\n",
+		  (const char *)err_msg);
+	  exit(256);
+	}
+      }
+      delete q;
+    }
+  }
+}
+
+
 void MainObject::InitMixers()
 {
   for(int i=0;i<RD_MAX_CARDS;i++) {
@@ -2060,7 +2133,7 @@ void QApplication::saveState(QSessionManager &sm) {
 bool MainObject::CheckLame()
 {
 #ifdef HAVE_LAME
-  return dlopen("libmp3lame.so",RTLD_LAZY)!=NULL;
+  return dlopen("libmp3lame.so.0",RTLD_LAZY)!=NULL;
 #else
   return false;
 #endif  // HAVE_LAME
@@ -2070,8 +2143,8 @@ bool MainObject::CheckLame()
 bool MainObject::CheckMp4Decode()
 {
 #ifdef HAVE_MP4_LIBS
-  return (dlopen("libfaad.so",RTLD_LAZY)!=NULL)&&
-    (dlopen("libmp4v2.so",RTLD_LAZY)!=NULL);
+  return (dlopen("libfaad.so.2",RTLD_LAZY)!=NULL)&&
+    (dlopen("libmp4v2.so.2",RTLD_LAZY)!=NULL);
 #else
   return false;
 #endif  // HAVE_MP4_LIBS
@@ -2081,7 +2154,7 @@ bool MainObject::CheckMp4Decode()
 bool MainObject::LoadTwoLame()
 {
 #ifdef HAVE_TWOLAME
-  if((twolame_handle=dlopen("libtwolame.so",RTLD_NOW))==NULL) {
+  if((twolame_handle=dlopen("libtwolame.so.0",RTLD_NOW))==NULL) {
     LogLine(RDConfig::LogInfo,
 	 "TwoLAME encoder library not found, MPEG L2 encoding not supported");
     return false;
@@ -2168,7 +2241,7 @@ void MainObject::FreeTwoLameEncoder(int card,int stream)
 bool MainObject::LoadMad()
 {
 #ifdef HAVE_MAD
-  if((mad_handle=dlopen("libmad.so",RTLD_NOW))==NULL) {
+  if((mad_handle=dlopen("libmad.so.0",RTLD_NOW))==NULL) {
     LogLine(RDConfig::LogInfo,
 	 "MAD decoder library not found, MPEG L2 decoding not supported");
     return false;
