@@ -2,9 +2,7 @@
 //
 // Edit an RDPanel Configuration
 //
-//   (C) Copyright 2002-2007 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: edit_rdpanel.cpp,v 1.9.8.1 2013/03/09 00:21:11 cvs Exp $
+//   (C) Copyright 2002-2007,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -43,8 +41,9 @@
 #include <edit_now_next.h>
 
 
-EditRDPanel::EditRDPanel(RDStation *station,QWidget *parent,const char *name)
-  : QDialog(parent,name,true)
+EditRDPanel::EditRDPanel(RDStation *station,RDStation *cae_station,
+			 QWidget *parent)
+  : QDialog(parent,"",true)
 {
   QString sql;
   RDSqlQuery *q;
@@ -72,28 +71,28 @@ EditRDPanel::EditRDPanel(RDStation *station,QWidget *parent,const char *name)
   //
   // Text Validator
   //
-  RDTextValidator *validator=new RDTextValidator(this,"validator");
+  RDTextValidator *validator=new RDTextValidator(this);
 
   //
   // Dialog Name
   //
-  setCaption(tr("RDPanel config for ")+station->name());
+  setCaption(tr("Configure RDPanel"));
 
   //
   // Channel Assignments Section
   //
-  QLabel *label=new QLabel(tr("Channel Assignments"),this,"globals_label");
+  QLabel *label=new QLabel(tr("Channel Assignments"),this);
   label->setFont(big_font);
   label->setGeometry(10,10,200,16);
 
   //
   // Sound Panel First Play Output
   //
-  label=new QLabel(tr("SoundPanel First Play Output"),this,"globals_label");
+  label=new QLabel(tr("SoundPanel First Play Output"),this);
   label->setFont(small_font);
 //  label->setGeometry(395,32,300,16);
   label->setGeometry(20,32,300,16);
-  air_card_sel[0]=new RDCardSelector(this,"air_card5_sel");
+  air_card_sel[0]=new RDCardSelector(this);
   air_card_sel[0]->setGeometry(15,50,120,117);
   air_start_rml_edit[0]=new QLineEdit(this);
   air_start_rml_edit[0]->setGeometry(205,50,160,19);
@@ -111,10 +110,10 @@ EditRDPanel::EditRDPanel(RDStation *station,QWidget *parent,const char *name)
   //
   // Sound Panel Second Play Output
   //
-  label=new QLabel(tr("SoundPanel Second Play Output"),this,"globals_label");
+  label=new QLabel(tr("SoundPanel Second Play Output"),this);
   label->setFont(small_font);
   label->setGeometry(20,100,300,16);
-  air_card_sel[1]=new RDCardSelector(this,"air_card5_sel");
+  air_card_sel[1]=new RDCardSelector(this);
   air_card_sel[1]->setGeometry(15,118,120,117);
   air_start_rml_edit[1]=new QLineEdit(this);
   air_start_rml_edit[1]->setGeometry(205,118,160,19);
@@ -132,10 +131,10 @@ EditRDPanel::EditRDPanel(RDStation *station,QWidget *parent,const char *name)
   //
   // Sound Panel Third Play Output
   //
-  label=new QLabel(tr("SoundPanel Third Play Output"),this,"globals_label");
+  label=new QLabel(tr("SoundPanel Third Play Output"),this);
   label->setFont(small_font);
   label->setGeometry(20,168,300,16);
-  air_card_sel[2]=new RDCardSelector(this,"air_card5_sel");
+  air_card_sel[2]=new RDCardSelector(this);
   air_card_sel[2]->setGeometry(15,186,120,117);
   air_start_rml_edit[2]=new QLineEdit(this);
   air_start_rml_edit[2]->setGeometry(205,186,160,19);
@@ -153,10 +152,10 @@ EditRDPanel::EditRDPanel(RDStation *station,QWidget *parent,const char *name)
   //
   // Sound Panel Fourth Play Output
   //
-  label=new QLabel(tr("SoundPanel Fourth Play Output"),this,"globals_label");
+  label=new QLabel(tr("SoundPanel Fourth Play Output"),this);
   label->setFont(small_font);
   label->setGeometry(20,236,300,16);
-  air_card_sel[3]=new RDCardSelector(this,"air_card5_sel");
+  air_card_sel[3]=new RDCardSelector(this);
   air_card_sel[3]->setGeometry(15,254,120,117);
   air_start_rml_edit[3]=new QLineEdit(this);
   air_start_rml_edit[3]->setGeometry(205,254,160,19);
@@ -174,11 +173,10 @@ EditRDPanel::EditRDPanel(RDStation *station,QWidget *parent,const char *name)
   //
   // Sound Panel Fifth Play Output
   //
-  label=new QLabel(tr("SoundPanel Fifth and Later Play Output"),
-		   this,"globals_label");
+  label=new QLabel(tr("SoundPanel Fifth and Later Play Output"),this);
   label->setFont(small_font);
   label->setGeometry(20,304,300,16);
-  air_card_sel[4]=new RDCardSelector(this,"air_card5_sel");
+  air_card_sel[4]=new RDCardSelector(this);
   air_card_sel[4]->setGeometry(15,322,120,117);
   air_start_rml_edit[4]=new QLineEdit(this);
   air_start_rml_edit[4]->setGeometry(205,322,160,19);
@@ -196,10 +194,10 @@ EditRDPanel::EditRDPanel(RDStation *station,QWidget *parent,const char *name)
   //
   // Sound Panel Cue Play Output
   //
-  label=new QLabel(tr("SoundPanel Cue Output"),this,"globals_label");
+  label=new QLabel(tr("SoundPanel Cue Output"),this);
   label->setFont(small_font);
   label->setGeometry(20,372,300,16);
-  air_card_sel[5]=new RDCardSelector(this,"air_card5_sel");
+  air_card_sel[5]=new RDCardSelector(this);
   air_card_sel[5]->setGeometry(15,390,120,117);
   air_start_rml_edit[5]=new QLineEdit(this);
   air_start_rml_edit[5]->setGeometry(205,390,160,19);
@@ -217,27 +215,26 @@ EditRDPanel::EditRDPanel(RDStation *station,QWidget *parent,const char *name)
   //
   // Display Settings Section
   //
-  label=new QLabel(tr("Display Settings"),this,"globals_label");
+  label=new QLabel(tr("Display Settings"),this);
   label->setFont(big_font);
   label->setGeometry(20,438,200,16);
 
   //
   // Skin Path
   //
-  air_skin_edit=new QLineEdit(this,"air_skin_edit");
+  air_skin_edit=new QLineEdit(this);
   air_skin_edit->setGeometry(135,460,180,20);
-  label=new QLabel(air_skin_edit,tr("Background Image:"),
-		   this,"air_skin_label");
+  label=new QLabel(air_skin_edit,tr("Background Image:"),this);
   label->setGeometry(10,460,115,20);
   label->setAlignment(AlignRight|AlignVCenter);
-  QPushButton *button=new QPushButton(tr("Select"),this,"skin_select_button");
+  QPushButton *button=new QPushButton(tr("Select"),this);
   button->setGeometry(320,458,50,25);
   connect(button,SIGNAL(clicked()),this,SLOT(selectSkinData()));
 
   //
   // Sound Panel Section
   //
-  label=new QLabel(tr("Sound Panel Settings"),this,"globals_label");
+  label=new QLabel(tr("Sound Panel Settings"),this);
   label->setFont(big_font);
 //  label->setGeometry(430,179,200,16);
   label->setGeometry(430,10,200,16);
@@ -245,81 +242,74 @@ EditRDPanel::EditRDPanel(RDStation *station,QWidget *parent,const char *name)
   //
   // # of Station Panels
   //
-  air_station_box=new QSpinBox(this,"air_station_box");
+  air_station_box=new QSpinBox(this);
   air_station_box->setGeometry(510,35,50,20);
   air_station_box->setRange(0,MAX_PANELS);
   air_station_box->setSpecialValueText(tr("None"));
-  air_station_label=new QLabel(air_station_box,tr("Host Panels:"),
-			     this,"air_station_label");
+  air_station_label=new QLabel(air_station_box,tr("Host Panels:"),this);
   air_station_label->setGeometry(405,35,100,20);
   air_station_label->setAlignment(AlignRight|AlignVCenter);
 
   //
   // # of User Panels
   //
-  air_user_box=new QSpinBox(this,"air_user_box");
+  air_user_box=new QSpinBox(this);
   air_user_box->setGeometry(510,57,50,20);
   air_user_box->setRange(0,MAX_PANELS);
   air_user_box->setSpecialValueText(tr("None"));
-  air_user_label=new QLabel(air_user_box,tr("User Panels:"),
-			     this,"air_user_label");
+  air_user_label=new QLabel(air_user_box,tr("User Panels:"),this);
   air_user_label->setGeometry(405,57,100,20);
   air_user_label->setAlignment(AlignRight|AlignVCenter);
 
   //
   // Flash Active Button
   //
-  air_flash_box=new QCheckBox(this,"air_flash_box");
+  air_flash_box=new QCheckBox(this);
   air_flash_box->setGeometry(435,85,15,15);
-  label=new QLabel(air_flash_box,tr("Flash Active Buttons"),
-			     this,"air_flash_label");
+  label=new QLabel(air_flash_box,tr("Flash Active Buttons"),this);
   label->setGeometry(455,85,150,15);
   label->setAlignment(AlignLeft|AlignVCenter);
 
   //
   // Pause Panel Button
   //
-  air_panel_pause_box=new QCheckBox(this,"air_panel_pause_box");
+  air_panel_pause_box=new QCheckBox(this);
   air_panel_pause_box->setGeometry(435,107,15,15);
-  label=new QLabel(air_panel_pause_box,tr("Enable Button Pausing"),
-			     this,"air_panel_pause_label");
+  label=new QLabel(air_panel_pause_box,tr("Enable Button Pausing"),this);
   label->setGeometry(455,107,150,15);
   label->setAlignment(AlignLeft|AlignVCenter);
 
   //
   // Clear Cart Filter
   //
-  air_clearfilter_box=new QCheckBox(this,"air_clearfilter_box");
+  air_clearfilter_box=new QCheckBox(this);
   air_clearfilter_box->setGeometry(435,129,15,15);
-  label=new QLabel(air_clearfilter_box,tr("Clear Cart Search Filter"),
-		   this,"air_clearfilter_label");
+  label=new QLabel(air_clearfilter_box,tr("Clear Cart Search Filter"),this);
   label->setGeometry(455,129,150,15);
   label->setAlignment(AlignLeft|AlignVCenter);
 
   //
   // Default Service
   //
-  air_defaultsvc_box=new QComboBox(this,"air_defaultsvc_box");
+  air_defaultsvc_box=new QComboBox(this);
   air_defaultsvc_box->setGeometry(520,151,100,20);
-  label=new QLabel(air_defaultsvc_box,tr("Default Service:"),
-		   this,"air_defaultsvc_label");
+  label=new QLabel(air_defaultsvc_box,tr("Default Service:"),this);
   label->setGeometry(385,151,130,20);
   label->setAlignment(AlignRight|AlignVCenter);
 
   //
   // Label Template
   //
-  air_label_template_edit=new QLineEdit(this,"air_label_template_edit");
+  air_label_template_edit=new QLineEdit(this);
   air_label_template_edit->setGeometry(520,173,sizeHint().width()-530,20);
-  label=new QLabel(air_label_template_edit,tr("Label Template:"),
-		   this,"air_label_template_label");
+  label=new QLabel(air_label_template_edit,tr("Label Template:"),this);
   label->setGeometry(415,173,100,20);
   label->setAlignment(AlignRight|AlignVCenter);
 
   //
   //  Ok Button
   //
-  button=new QPushButton(this,"ok_button");
+  button=new QPushButton(this);
   button->setGeometry(sizeHint().width()-180,sizeHint().height()-60,80,50);
   button->setDefault(true);
   button->setFont(small_font);
@@ -329,7 +319,7 @@ EditRDPanel::EditRDPanel(RDStation *station,QWidget *parent,const char *name)
   //
   //  Cancel Button
   //
-  button=new QPushButton(this,"cancel_button");
+  button=new QPushButton(this);
   button->setGeometry(sizeHint().width()-90,sizeHint().height()-60,80,50);
   button->setFont(small_font);
   button->setText(tr("&Cancel"));
@@ -340,9 +330,9 @@ EditRDPanel::EditRDPanel(RDStation *station,QWidget *parent,const char *name)
   //
   if(station->scanned()) {
     for(int i=0;i<6;i++) {
-      air_card_sel[i]->setMaxCards(station->cards());
+      air_card_sel[i]->setMaxCards(cae_station->cards());
       for(int j=0;j<air_card_sel[i]->maxCards();j++) {
-	air_card_sel[i]->setMaxPorts(j,station->cardOutputs(j));
+	air_card_sel[i]->setMaxPorts(j,cae_station->cardOutputs(j));
       }
     }
   }
