@@ -2,9 +2,7 @@
 //
 // List Rivendell Groups
 //
-//   (C) Copyright 2002 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: list_groups.h,v 1.13 2010/07/29 19:32:34 cvs Exp $
+//   (C) Copyright 2002,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -32,12 +30,11 @@
 #include <rdlistviewitem.h>
 #include <rddb.h>
 
-
 class ListGroups : public QDialog
 {
   Q_OBJECT
  public:
-  ListGroups(QWidget *parent=0,const char *name=0);
+  ListGroups(QWidget *parent=0);
   ~ListGroups();
   QSize sizeHint() const;
   QSizePolicy sizePolicy() const;
