@@ -2,9 +2,7 @@
 //
 // List Rivendell Services
 //
-//   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: list_svcs.cpp,v 1.26 2010/07/29 19:32:35 cvs Exp $
+//   (C) Copyright 2002-2003,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -32,13 +30,13 @@
 #include <qbuttongroup.h>
 #include <rddb.h>
 
-#include <list_svcs.h>
-#include <edit_svc.h>
-#include <add_svc.h>
+#include "add_svc.h"
+#include "edit_svc.h"
+#include "globals.h"
+#include "list_svcs.h"
 
-
-ListSvcs::ListSvcs(QWidget *parent,const char *name)
-  : QDialog(parent,name,true)
+ListSvcs::ListSvcs(QWidget *parent)
+  : QDialog(parent,"",true)
 {
   //
   // Fix the Window Size
@@ -61,7 +59,7 @@ ListSvcs::ListSvcs(QWidget *parent,const char *name)
   //
   //  Add Button
   //
-  QPushButton *add_button=new QPushButton(this,"add_button");
+  QPushButton *add_button=new QPushButton(this);
   add_button->setGeometry(100,30,80,50);
   add_button->setFont(font);
   add_button->setText(tr("&Add"));
@@ -70,7 +68,7 @@ ListSvcs::ListSvcs(QWidget *parent,const char *name)
   //
   //  Edit Button
   //
-  QPushButton *edit_button=new QPushButton(this,"edit_button");
+  QPushButton *edit_button=new QPushButton(this);
   edit_button->setGeometry(100,90,80,50);
   edit_button->setFont(font);
   edit_button->setText(tr("&Edit"));
@@ -79,7 +77,7 @@ ListSvcs::ListSvcs(QWidget *parent,const char *name)
   //
   //  Delete Button
   //
-  QPushButton *delete_button=new QPushButton(this,"delete_button");
+  QPushButton *delete_button=new QPushButton(this);
   delete_button->setGeometry(100,150,80,50);
   delete_button->setFont(font);
   delete_button->setText(tr("&Delete"));
@@ -88,7 +86,7 @@ ListSvcs::ListSvcs(QWidget *parent,const char *name)
   //
   //  Close Button
   //
-  QPushButton *close_button=new QPushButton(this,"close_button");
+  QPushButton *close_button=new QPushButton(this);
   close_button->setGeometry(100,240,80,50);
   close_button->setDefault(true);
   close_button->setFont(font);
@@ -98,10 +96,9 @@ ListSvcs::ListSvcs(QWidget *parent,const char *name)
   //
   // Services List Box
   //
-  list_box=new QListBox(this,"list_box");
+  list_box=new QListBox(this);
   list_box->setGeometry(10,30,80,260);
-  QLabel *list_box_label=new QLabel(list_box,tr("&Services:"),
-				    this,"list_box_label");
+  QLabel *list_box_label=new QLabel(list_box,tr("&Services:"),this);
   list_box_label->setFont(font);
   list_box_label->setGeometry(14,11,85,19);
   connect(list_box,SIGNAL(doubleClicked(QListBoxItem *)),
@@ -133,7 +130,7 @@ void ListSvcs::addData()
 {
   QString svcname;
 
-  AddSvc *add_svc=new AddSvc(&svcname,this,"add_svc");
+  AddSvc *add_svc=new AddSvc(&svcname,this);
   if(add_svc->exec()<0) {
     delete add_svc;
     return;
@@ -148,7 +145,7 @@ void ListSvcs::editData()
   if(list_box->currentItem()<0) {
     return;
   }
-  EditSvc *edit_svc=new EditSvc(list_box->currentText(),this,"edit_svc");
+  EditSvc *edit_svc=new EditSvc(list_box->currentText(),this);
   edit_svc->exec();
   delete edit_svc;
 }
@@ -188,7 +185,7 @@ void ListSvcs::deleteData()
     }
   }
   delete q;
-  RDSvc *svc=new RDSvc(list_box->currentText());
+  RDSvc *svc=new RDSvc(list_box->currentText(),admin_station,admin_config);
   svc->remove();
   delete svc;
   list_box->removeItem(list_box->currentItem());
