@@ -2,9 +2,7 @@
 //
 // Audio card selector widget for Rivendell
 //
-//   (C) Copyright 2002-2007 Fred Gleason <fredg@paravelsystems.com>
-//
-//    $Id: rdhpicardselector.cpp,v 1.3 2010/07/29 19:32:36 cvs Exp $
+//   (C) Copyright 2002-2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -36,8 +34,8 @@
 #include <rdhpicardselector.h>
 
 
-RDHPICardSelector::RDHPICardSelector(QWidget *parent,const char *name)
-  : QWidget(parent,name)
+RDHPICardSelector::RDHPICardSelector(QWidget *parent)
+  : QWidget(parent)
 {
   QFont font;
 
@@ -52,7 +50,7 @@ RDHPICardSelector::RDHPICardSelector(QWidget *parent,const char *name)
   //
   // Title
   //
-  card_title=new QLabel(this,"card_title");
+  card_title=new QLabel(this);
   card_title->setGeometry(0,0,geometry().width(),19);
   card_title->setFont(font);
   card_title->setAlignment(AlignHCenter);
@@ -61,29 +59,27 @@ RDHPICardSelector::RDHPICardSelector(QWidget *parent,const char *name)
   //
   // Card
   //
-  card_card_box=new QSpinBox(this,"card_card_box");
+  card_card_box=new QSpinBox(this);
   card_card_box->setGeometry(60,yoffset,50,19);
   card_card_box->setSpecialValueText("None");
   card_card_box->setMinValue(-1);
   card_card_box->setMaxValue(HPI_MAX_ADAPTERS-1);
   card_card_box->setValue(-1);
   connect(card_card_box,SIGNAL(valueChanged(int)),this,SLOT(cardData(int)));
-  card_card_label=new QLabel(card_card_box,"Card:",this,
-				       "card_card_label");
+  card_card_label=new QLabel(card_card_box,"Card:",this);
   card_card_label->setGeometry(0,yoffset+2,55,19);
   card_card_label->setAlignment(AlignRight|ShowPrefix);
 
   //
   // Port
   //
-  card_port_box=new QSpinBox(this,"card_port_box");
+  card_port_box=new QSpinBox(this);
   card_port_box->setGeometry(60,yoffset+22,50,19);
   card_port_box->setMinValue(0);
   card_port_box->setMaxValue(HPI_MAX_NODES-1);
   card_port_box->setDisabled(true);
   connect(card_port_box,SIGNAL(valueChanged(int)),this,SLOT(portData(int)));
-  card_port_label=new QLabel(card_port_box,"Port:",this,
-				       "card_port_label");
+  card_port_label=new QLabel(card_port_box,"Port:",this);
   card_port_label->setGeometry(0,yoffset+24,55,19);
   card_port_label->setAlignment(AlignRight|ShowPrefix);
 }
