@@ -2,9 +2,7 @@
 //
 // Select a Set of Dates for a Rivendell Report
 //
-//   (C) Copyright 2002-2006 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: pick_report_dates.cpp,v 1.8.8.2 2013/01/22 20:59:39 cvs Exp $
+//   (C) Copyright 2002-2006,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -32,10 +30,8 @@
 #include <globals.h>
 #include <pick_report_dates.h>
 
-
-PickReportDates::PickReportDates(const QString &svcname,
-				   QWidget *parent,const char *name)
-  : QDialog(parent,name,true)
+PickReportDates::PickReportDates(const QString &svcname,QWidget *parent)
+  : QDialog(parent,"",true)
 {
   QString sql;
   RDSqlQuery *q;
@@ -63,10 +59,9 @@ PickReportDates::PickReportDates(const QString &svcname,
   //
   // Report List
   //
-  edit_report_box=new QComboBox(this,"edit_report_box");
+  edit_report_box=new QComboBox(this);
   edit_report_box->setGeometry(75,11,sizeHint().width()-85,19);
-  QLabel *label=new QLabel(edit_report_box,tr("&Report:"),
-				      this,"edit_report_label");
+  QLabel *label=new QLabel(edit_report_box,tr("&Report:"),this);
   label->setGeometry(10,11,60,19);
   label->setFont(bold_font);
   label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
@@ -82,15 +77,14 @@ PickReportDates::PickReportDates(const QString &svcname,
   //
   // Start Date
   //
-  edit_startdate_edit=new QDateEdit(this,"edit_startdate_edit");
+  edit_startdate_edit=new QDateEdit(this);
   edit_startdate_edit->setGeometry(150,35,100,22);
   edit_startdate_edit->setDate(yesterday_date);
-  label=new QLabel(edit_startdate_edit,tr("&Start Date:"),
-				      this,"edit_startdate_label");
+  label=new QLabel(edit_startdate_edit,tr("&Start Date:"),this);
   label->setGeometry(75,36,70,19);
   label->setFont(bold_font);
   label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
-  QPushButton *button=new QPushButton(this,"startdate_button");
+  QPushButton *button=new QPushButton(this);
   button->setGeometry(260,33,50,27);
   button->setFont(font);
   button->setText(tr("&Select"));
@@ -99,15 +93,14 @@ PickReportDates::PickReportDates(const QString &svcname,
   //
   // End Date
   //
-  edit_enddate_edit=new QDateEdit(this,"edit_enddate_edit");
+  edit_enddate_edit=new QDateEdit(this);
   edit_enddate_edit->setGeometry(150,65,100,22);
   edit_enddate_edit->setDate(yesterday_date);
-  label=new QLabel(edit_enddate_edit,tr("&End Date:"),
-				      this,"edit_enddate_label");
+  label=new QLabel(edit_enddate_edit,tr("&End Date:"),this);
   label->setGeometry(75,66,70,19);
   label->setFont(bold_font);
   label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
-  button=new QPushButton(this,"enddate_button");
+  button=new QPushButton(this);
   button->setGeometry(260,63,50,27);
   button->setFont(font);
   button->setText(tr("&Select"));
@@ -116,7 +109,7 @@ PickReportDates::PickReportDates(const QString &svcname,
   //
   //  Generate Button
   //
-  button=new QPushButton(this,"list_purge_button");
+  button=new QPushButton(this);
   button->setGeometry(10,sizeHint().height()-60,80,50);
   button->setFont(bold_font);
   button->setText(tr("&Generate\nReport"));
@@ -125,7 +118,7 @@ PickReportDates::PickReportDates(const QString &svcname,
   //
   //  Close Button
   //
-  button=new QPushButton(this,"close_button");
+  button=new QPushButton(this);
   button->setGeometry(sizeHint().width()-90,sizeHint().height()-60,80,50);
   button->setDefault(true);
   button->setFont(bold_font);
@@ -185,7 +178,8 @@ void PickReportDates::generateData()
 		 tr("The end date cannot be earlier than the start date!"));
     return;
   }
-  RDReport *report=new RDReport(edit_report_box->currentText(),this);
+  RDReport *report=
+    new RDReport(edit_report_box->currentText(),rdstation_conf,log_config,this);
   if((edit_startdate_edit->date()!=edit_enddate_edit->date())&&
      (!RDReport::multipleDaysAllowed(report->filter()))) {
     QMessageBox::warning(this,tr("Invalid Date Range"),
@@ -201,11 +195,15 @@ void PickReportDates::generateData()
     return;
   }
 #ifdef WIN32
-  QString filename=RDDateDecode(report->exportPath(RDReport::Windows),
-				edit_startdate_edit->date());
+  QString filename=
+    RDDateDecode(report->exportPath(RDReport::Windows),
+		 edit_startdate_edit->date(),rdstation_conf,log_config,
+		 edit_svcname);
 #else
-  QString filename=RDDateDecode(report->exportPath(RDReport::Linux),
-				edit_startdate_edit->date());
+  QString filename=
+    RDDateDecode(report->exportPath(RDReport::Linux),
+		 edit_startdate_edit->date(),rdstation_conf,log_config,
+		 edit_svcname);
 #endif
   QFile file(filename);
   if(file.exists()) {
@@ -228,7 +226,8 @@ void PickReportDates::generateData()
 	break;
 
       case RDReport::ErrorCantOpen:
-	QMessageBox::warning(this,"File Error","Unable to open report file!");
+	QMessageBox::warning(this,"File Error","Unable to open report file at"+
+			     QString("\"")+out_path+"\"!");
 	break;
 
       case RDReport::ErrorCanceled:
