@@ -121,7 +121,7 @@ tene&amp;ster</translation>
     <message>
         <source>Are you sure you want to
 delete</source>
-        <translation>Er du sikker på at du vil
+        <translation type="obsolete">Er du sikker på at du vil
 sletta</translation>
     </message>
     <message>
@@ -186,6 +186,15 @@ Vil du lagra?</translation>
         <source>Remarks</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>&amp;Clone</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Are you sure you want to delete
+</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditEvent</name>
@@ -525,6 +534,10 @@ Vil du byta henne ut?</translation>
         <source>IMPORT</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>and code</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditEventLine</name>
@@ -602,6 +615,18 @@ ei anna hending som finst frå før.</translation>
 &amp;All</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Clear Clocks</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Are you sure you want to update ALL clocks in the grid?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>This operation cannot be undone!</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditNote</name>
@@ -843,6 +868,30 @@ Flettar du på nytt, vil du fjerna desse dataa. Flett på nytt?</translation>
         <source>Generate Log - User: </source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to generate log</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to clear traffic links</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to clear music links</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to link music log</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to link traffic log</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ImportListView</name>
